==> deptools-1.6.0.tar.gz: deptools-1.6.0/CHANGELOG.md <==
# AlazarTech Deployment Tools Change Log

This file contains all important changes to the AlazarTech deployment tools

## [1.6.0] - 2022-04-25
### Added
- Support for cross-referenced issues. [#38]
- register.py - log target URL. [#39]

## [1.5.4] - 2022-03-16
### Fixed
- Issue where running `createversionfile` on a repo with no existing tag would
  fail. Note that it is necessary for the repo to have a `CHANGELOG.md` file and
  an existing commit for this command to work. [#37]

## [1.5.3] - 2021-12-21
### Added
- Support for Python 3.10. [#36]

## [1.5.2] - 2021-11-03
### Added
- Register uses passfile instead of password. [#34]

## [1.5.1] - 2021-09-14
### Added
- Support for website registration. [#32]

## [1.4.0] - 2021-07-20
### Added
- Support for running createversionfile outside of CI. [#29]

### Changed
- Sign files using alazarsign. [#30]

## [1.3.0] - 2020-03-24
### Added
- createversionfile script. [#28]

## [1.2.2] - 2020-03-23
### Fixed
- Issue that prevented the release of v1.2.1

## [1.2.1] - 2020-03-23
### Fixed
- Issue that prevented the release of v1.2.0

## [1.2.0] - 2020-03-22
### Added
- run-clang-format tool

## [1.1.1] - 2020-11-24
### Fixed
- Remove debugging statements

## [1.1.0] - 2020-11-23
### Added
- Full support for SemVer 2.0.0 version numbers in change logs. [#25]
- Add `-o` option to `changelogparser version`. [#26]

## [1.0.1] - 2020-11-03
### Fixed
- Issue with v1.0.0 release, where deploy failed because of the missing Azure
  python dependency. [#24]

## [1.0.0] - 2020-10-27
### Added
- Support for artifacts upload on Azure blob storage used by
  alazar-package-manager [#23]

## [0.4.2] - 2020-09-02
### Fixed
- Issue with v0.4.1 release, where the package couldn't be installed from PyPI
  [#22]

## [0.4.1] - 2020-05-19
### Changed
- Use new code signing certificate

## [0.4.0] - 2020-05-07
### Added
- Support for ticket references in change log items [#19]

### Fixed
- Issue where H3 tags are not closed properly in changelogparser's HTML output

## [0.3.4] - 2019-10-03
### Fixed
- Issue where deploy did not work correctly with Python 2

## [0.3.3] - 2019-09-27
### Added
- Support for Markdown output
- Support for Python 2.7

## [0.3.2] - 2019-07-23
### Fixed
- Spec file build issue when version log is empty

## [0.3.1] - 2019-07-23
### Fixed
- Build issues when version log is empty

## [0.3.0] - 2019-05-06
### Added
- deploy: split "encrypt" into "compress" and "encrypt". This adds support for
  creating non-password protected ZIP files [#10]
- deploy: add "destdir" option [#11]

### Fixed
- Build issues by using a "version.txt" file for this package

## [0.2.0] - 2019-05-02
### Added
- Support for "YANKED" tag in change log files [#4]
- Add option to publish only encrypted files, and option to read password from
  file. [#6]
- Support publishing to FTP sites [#5]
- Add "tospec" to changelogparser [#8]
- Deploy to AlazarTech's PyPI server [#9]

### Changed
- Make encrypt's default value "no" in deploy.py [#7]

## [0.1.0] - 2019-03-20
### Added
- Change log parser utility [#3]

## [0.0.2] - 2019-01-25
### Fixed
- Make directory copy work even if destination already exists

## [0.0.1] - 2019-01-23
### Added
- Initial version: deploy.py [#1]

==> deptools-1.6.2.tar.gz: deptools-1.6.2/CHANGELOG.md <==
# AlazarTech Deployment Tools Change Log

This file contains all important changes to the AlazarTech deployment tools

## [1.6.2] - 2022-04-28
### Added
- Add exclude field to spec.py to exclude files from pattern. [#42]

## [1.6.1] - 2022-04-28
### Changed
- Prefix production URL in register.py with "www". [#40]
- Make changelogparser emit an error if dates or versions are not in descending
  order. [#41]

## [1.6.0] - 2022-04-25
### Added
- Support for cross-referenced issues. [#38]
- register.py - log target URL. [#39]

## [1.5.4] - 2022-03-16
### Fixed
- Issue where running `createversionfile` on a repo with no existing tag would
  fail. Note that it is necessary for the repo to have a `CHANGELOG.md` file and
  an existing commit for this command to work. [#37]

## [1.5.3] - 2021-12-21
### Added
- Support for Python 3.10. [#36]

## [1.5.2] - 2021-11-03
### Added
- Register uses passfile instead of password. [#34]

## [1.5.1] - 2021-09-14
### Added
- Support for website registration. [#32]

## [1.4.0] - 2021-07-20
### Added
- Support for running createversionfile outside of CI. [#29]

### Changed
- Sign files using alazarsign. [#30]

## [1.3.0] - 2021-03-24
### Added
- createversionfile script. [#28]

## [1.2.2] - 2021-03-23
### Fixed
- Issue that prevented the release of v1.2.1

## [1.2.1] - 2021-03-23
### Fixed
- Issue that prevented the release of v1.2.0

## [1.2.0] - 2021-03-22
### Added
- run-clang-format tool

## [1.1.1] - 2020-11-24
### Fixed
- Remove debugging statements

## [1.1.0] - 2020-11-23
### Added
- Full support for SemVer 2.0.0 version numbers in change logs. [#25]
- Add `-o` option to `changelogparser version`. [#26]

## [1.0.1] - 2020-11-03
### Fixed
- Issue with v1.0.0 release, where deploy failed because of the missing Azure
  python dependency. [#24]

## [1.0.0] - 2020-10-27
### Added
- Support for artifacts upload on Azure blob storage used by
  alazar-package-manager [#23]

## [0.4.2] - 2020-09-02
### Fixed
- Issue with v0.4.1 release, where the package couldn't be installed from PyPI
  [#22]

## [0.4.1] - 2020-05-19
### Changed
- Use new code signing certificate

## [0.4.0] - 2020-05-07
### Added
- Support for ticket references in change log items [#19]

### Fixed
- Issue where H3 tags are not closed properly in changelogparser's HTML output

## [0.3.4] - 2019-10-03
### Fixed
- Issue where deploy did not work correctly with Python 2

## [0.3.3] - 2019-09-27
### Added
- Support for Markdown output
- Support for Python 2.7

## [0.3.2] - 2019-07-23
### Fixed
- Spec file build issue when version log is empty

## [0.3.1] - 2019-07-23
### Fixed
- Build issues when version log is empty

## [0.3.0] - 2019-05-06
### Added
- deploy: split "encrypt" into "compress" and "encrypt". This adds support for
  creating non-password protected ZIP files [#10]
- deploy: add "destdir" option [#11]

### Fixed
- Build issues by using a "version.txt" file for this package

## [0.2.0] - 2019-05-02
### Added
- Support for "YANKED" tag in change log files [#4]
- Add option to publish only encrypted files, and option to read password from
  file. [#6]
- Support publishing to FTP sites [#5]
- Add "tospec" to changelogparser [#8]
- Deploy to AlazarTech's PyPI server [#9]

### Changed
- Make encrypt's default value "no" in deploy.py [#7]

## [0.1.0] - 2019-03-20
### Added
- Change log parser utility [#3]

## [0.0.2] - 2019-01-25
### Fixed
- Make directory copy work even if destination already exists

## [0.0.1] - 2019-01-23
### Added
- Initial version: deploy.py [#1]
